@@ -12,4 +12,8 @@ pub enum DiscoverError {
     MissingArgument(String),
     #[error("Unbale to retrieve data from provider. Error message: `{0}`")]
     ProviderRequestFailed(String),
+    #[error(
+        "Unsupported provider `{0}`. Either the provider is not supported or it is not enabled."
+    )]
+    UnsupportedProvider(String),
 }
